# `splendaq`

[![Python package](https://github.com/splendor-collab/splendaq/actions/workflows/python-package.yml/badge.svg)](https://github.com/splendor-collab/splendaq/actions/workflows/python-package.yml) [![PyPI](https://img.shields.io/pypi/v/splendaq)](https://pypi.org/project/splendaq/) [![Python 3.6](https://img.shields.io/badge/python-3.6+-blue.svg)](https://www.python.org/downloads/release/python-360/) [![GitHub](https://img.shields.io/github/license/splendor-collab/splendaq)](https://github.com/splendor-collab/splendaq/blob/main/LICENSE)


Package for general data acquisition with a focus on the Moku device by [Liquid Instruments](https://www.liquidinstruments.com/).
